@@ -21,10 +21,8 @@ IncidenceEditorSettings *IncidenceEditorSettings::self()
     return mSelf;
 }
 
-IncidenceEditorSettings::IncidenceEditorSettings()
-{
-}
+IncidenceEditorSettings::IncidenceEditorSettings() = default;
 
-IncidenceEditorSettings::~IncidenceEditorSettings()
-{
-}
+IncidenceEditorSettings::~IncidenceEditorSettings() = default;
+
+#include "moc_incidenceeditorsettings.cpp"
